@@ -29,7 +29,7 @@ shake<-function(pp, a=0.001)
 	pp
 }
 ####################################################################################
-minusID<-function(pp, minusR, dbh, atleast=0)
+minusID<-function(pp, minusR, dbh, atleast=0)#, lifeform, status)
 {
 	id<-( pp$x<(pp$window$x[2]-minusR) ) & (pp$x>(pp$window$x[1]+minusR)) & (pp$y<(pp$window$y[2]-minusR)) & (pp$y>(pp$window$y[1]+minusR)) 
 	if(!is.null(pp$dbh) & !missing(dbh))
@@ -37,7 +37,7 @@ minusID<-function(pp, minusR, dbh, atleast=0)
 	if(atleast>0)
 	{
 		fqs<-freqs(pp)
-		marks<-union(pp$marks,NULL)
+		marks<-names(fqs)
 		for(m in 1:length(marks))	
 		{
 			bad<-which(pp$marks==marks[m])
@@ -45,5 +45,18 @@ minusID<-function(pp, minusR, dbh, atleast=0)
 				id[bad]<- FALSE
 		}
 	}
+#	if(!missing(lifeform))
+#	{
+#		sp<-levels(pp$marks)
+#		lfs<-bcispecies.lifeform(lifeform=lifeform)
+#		bad<-sp[!(sp%in%lfs)]
+#		for(s in bad)
+#			id[pp$marks==s]<-FALSE
+#	}
+#	if(!missing(status))
+#	{
+#		id[!(pp$status%in%status)]<-FALSE
+#	}
+	if(sum(is.na(id))>0) warning("Vector contains NA's.")
 	id
 }
